<?php
/**
 * Skin Setup
 *
 * @package CHINCHILLA
 * @since CHINCHILLA 1.76.0
 */


//--------------------------------------------
// SKIN DEFAULTS
//--------------------------------------------

// Return theme's (skin's) default value for the specified parameter
if ( ! function_exists( 'chinchilla_theme_defaults' ) ) {
	function chinchilla_theme_defaults( $name='', $value='' ) {
		$defaults = array(
			'page_width'          => 1290,
			'page_boxed_extra'  => 60,
			'page_fullwide_max' => 1920,
			'page_fullwide_extra' => 130,
			'sidebar_width'       => 410,
			'sidebar_gap'       => 40,
			'grid_gap'          => 30,
			'rad'               => 0,
		);
		if ( empty( $name ) ) {
			return $defaults;
		} else {
			if ( empty( $value ) && isset( $defaults[ $name ] ) ) {
				$value = $defaults[ $name ];
			}
			return $value;
		}
	}
}


// Theme init priorities:
// Action 'after_setup_theme'
// 1 - register filters to add/remove lists items in the Theme Options
// 2 - create Theme Options
// 3 - add/remove Theme Options elements
// 5 - load Theme Options. Attention! After this step you can use only basic options (not overriden)
// 9 - register other filters (for installer, etc.)
//10 - standard Theme init procedures (not ordered)
// Action 'wp_loaded'
// 1 - detect override mode. Attention! Only after this step you can use overriden options (separate values for the shop, courses, etc.)


//--------------------------------------------
// SKIN SETTINGS
//--------------------------------------------
if ( ! function_exists( 'chinchilla_skin_setup' ) ) {
	add_action( 'after_setup_theme', 'chinchilla_skin_setup', 1 );
	function chinchilla_skin_setup() {

		$GLOBALS['CHINCHILLA_STORAGE'] = array_merge( $GLOBALS['CHINCHILLA_STORAGE'], array(

			// Key validator: market[env|loc]-vendor[axiom|ancora|themerex]
			'theme_pro_key'       => 'env-ancora',

			'theme_doc_url'       => '//chinchilla.ancorathemes.com/doc',

			'theme_demofiles_url' => '//demofiles.ancorathemes.com/chinchilla/',

			'theme_rate_url'      => '//themeforest.net/download',

			'theme_custom_url'    => '//themerex.net/offers/?utm_source=offers&utm_medium=click&utm_campaign=themeinstall',

			'theme_support_url'   => '//themerex.net/support/',

			'theme_download_url'  => '//themeforest.net/item/chinchilla-animal-care-pet-shop-wordpress-theme/35011981',        // Ancora

			'theme_video_url'     => '//www.youtube.com/channel/UCdIjRh7-lPVHqTTKpaf8PLA',   // Ancora

			'theme_privacy_url'   => '//ancorathemes.com/privacy-policy/',                   // Ancora

			'portfolio_url'       => '//themeforest.net/user/ancorathemes/portfolio',        // Ancora

			// Comma separated slugs of theme-specific categories (for get relevant news in the dashboard widget)
			// (i.e. 'children,kindergarten')
			'theme_categories'    => '',
		) );
	}
}

// Add/remove/change Theme Settings
if ( ! function_exists( 'chinchilla_skin_setup_settings' ) ) {
	add_action( 'after_setup_theme', 'chinchilla_skin_setup_settings', 1 );
    function chinchilla_skin_setup_settings() {
        // Example: enable (true) / disable (false) thumbs in the prev/next navigation
        chinchilla_storage_set_array( 'settings', 'thumbs_in_navigation', false );
		chinchilla_storage_set_array2( 'required_plugins', 'revslider', 'install', true);
		chinchilla_storage_set_array2( 'required_plugins', 'quickcal', 'install', false);
		// Add Skin Specific Plugins
		chinchilla_storage_set_array( 'required_plugins', 'give', array(
			'title'       => esc_html__( 'Give', 'chinchilla' ),
			'description' => esc_html__( "The most robust, flexible, and intuitive way to accept donations on WordPress", 'chinchilla' ),
			'required'    => false,
			'logo'        => chinchilla_get_file_url( 'plugins/give/give.png' ),
			'group'       => 'ecommerce',
		) );
		$chinchilla_skin_path = chinchilla_get_file_dir( chinchilla_skins_get_current_skin_dir() . 'plugins/give/give.php' );
		if ( ! empty( $chinchilla_skin_path ) ) {
			require_once $chinchilla_skin_path;
		}
    }
}


//--------------------------------------------
// SKIN FONTS
//--------------------------------------------
if ( ! function_exists( 'chinchilla_skin_setup_fonts' ) ) {
	add_action( 'after_setup_theme', 'chinchilla_skin_setup_fonts', 1 );
	function chinchilla_skin_setup_fonts() {
		// Fonts to load when theme start
		// It can be:
		// - Google fonts (specify name, family and styles)
		// - Adobe fonts (specify name, family and link URL)
		// - uploaded fonts (specify name, family), placed in the folder css/font-face/font-name inside the skin folder
		// Attention! Font's folder must have name equal to the font's name, with spaces replaced on the dash '-'
		// example: font name 'TeX Gyre Termes', folder 'TeX-Gyre-Termes'
		chinchilla_storage_set(
			'load_fonts', array(
				array(
					'name'   => 'Laila',
					'family' => 'sans-serif',
					'link'   => '',
					'styles' => 'wght@300;400;500;600;700'
				),
				array(
					'name'   => 'Nunito',
					'family' => 'sans-serif',
					'link'   => '',
					'styles' => 'ital,wght@0,200;0,300;0,400;0,600;0,700;1,200;1,300;1,400;1,600;1,700'
				),
			)
		);

		// Characters subset for the Google fonts. Available values are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese
		chinchilla_storage_set( 'load_fonts_subset', 'latin,latin-ext' );

		// Settings of the main tags.
		// Default value of 'font-family' may be specified as reference to the array $load_fonts (see above)
		// or as comma-separated string.
		// In the second case (if 'font-family' is specified manually as comma-separated string):
		//    1) Font name with spaces in the parameter 'font-family' will be enclosed in the quotes and no spaces after comma!
		//    2) If font-family inherit a value from the 'Main text' - specify 'inherit' as a value
		// example:
		// Correct:   'font-family' => basekit_get_load_fonts_family_string( $load_fonts[0] )
		// Correct:   'font-family' => 'Roboto,sans-serif'
		// Correct:   'font-family' => '"PT Serif",sans-serif'
		// Incorrect: 'font-family' => 'Roboto, sans-serif'
		// Incorrect: 'font-family' => 'PT Serif,sans-serif'

		$font_description = esc_html__( 'Font settings for the %s of the site. To ensure that the elements scale properly on mobile devices, please use only the following units: "rem", "em" or "ex"', 'chinchilla' );

		chinchilla_storage_set(
			'theme_fonts', array(
				'p'       => array(
					'title'           => esc_html__( 'Main text', 'chinchilla' ),
					'description'     => sprintf( $font_description, esc_html__( 'main text', 'chinchilla' ) ),
					'font-family'     => 'Nunito,sans-serif',
					'font-size'       => '1rem',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.62em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0.1px',
					'margin-top'      => '0em',
					'margin-bottom'   => '1.57em',
				),
				'post'    => array(
					'title'           => esc_html__( 'Article text', 'chinchilla' ),
					'description'     => sprintf( $font_description, esc_html__( 'article text', 'chinchilla' ) ),
					'font-family'     => '',			// Example: '"PR Serif",serif',
					'font-size'       => '',			// Example: '1.286rem',
					'font-weight'     => '',			// Example: '400',
					'font-style'      => '',			// Example: 'normal',
					'line-height'     => '',			// Example: '1.75em',
					'text-decoration' => '',			// Example: 'none',
					'text-transform'  => '',			// Example: 'none',
					'letter-spacing'  => '',			// Example: '',
					'margin-top'      => '',			// Example: '0em',
					'margin-bottom'   => '',			// Example: '1.4em',
				),
				'h1'      => array(
					'title'           => esc_html__( 'Heading 1', 'chinchilla' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H1', 'chinchilla' ) ),
					'font-family'     => 'Laila,sans-serif',
					'font-size'       => '3.167em',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.088em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '-1.7px',
					'margin-top'      => '1.16em',
					'margin-bottom'   => '0.36em',
				),
				'h2'      => array(
					'title'           => esc_html__( 'Heading 2', 'chinchilla' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H2', 'chinchilla' ) ),
					'font-family'     => 'Laila,sans-serif',
					'font-size'       => '2.611em',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.106em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '0.83em',
					'margin-bottom'   => '0.44em',
				),
				'h3'      => array(
					'title'           => esc_html__( 'Heading 3', 'chinchilla' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H3', 'chinchilla' ) ),
					'font-family'     => 'Laila,sans-serif',
					'font-size'       => '1.944em',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.200em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '1.2em',
					'margin-bottom'   => '0.58em',
				),
				'h4'      => array(
					'title'           => esc_html__( 'Heading 4', 'chinchilla' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H4', 'chinchilla' ) ),
					'font-family'     => 'Laila,sans-serif',
					'font-size'       => '1.556em',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.214em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '1.43em',
					'margin-bottom'   => '0.6em',
				),
				'h5'      => array(
					'title'           => esc_html__( 'Heading 5', 'chinchilla' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H5', 'chinchilla' ) ),
					'font-family'     => 'Laila,sans-serif',
					'font-size'       => '1.333em',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.208em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '1.47em',
					'margin-bottom'   => '0.64em',
				),
				'h6'      => array(
					'title'           => esc_html__( 'Heading 6', 'chinchilla' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H6', 'chinchilla' ) ),
					'font-family'     => 'Laila,sans-serif',
					'font-size'       => '1.056em',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.474em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '1.75em',
					'margin-bottom'   => '0.8em',
				),
				'logo'    => array(
					'title'           => esc_html__( 'Logo text', 'chinchilla' ),
					'description'     => sprintf( $font_description, esc_html__( 'text of the logo', 'chinchilla' ) ),
					'font-family'     => 'Laila,sans-serif',
					'font-size'       => '1.7em',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.25em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'button'  => array(
					'title'           => esc_html__( 'Buttons', 'chinchilla' ),
					'description'     => sprintf( $font_description, esc_html__( 'buttons', 'chinchilla' ) ),
					'font-family'     => 'Laila,sans-serif',
					'font-size'       => '16px',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '21px',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'input'   => array(
					'title'           => esc_html__( 'Input fields', 'chinchilla' ),
					'description'     => sprintf( $font_description, esc_html__( 'input fields, dropdowns and textareas', 'chinchilla' ) ),
					'font-family'     => 'inherit',
					'font-size'       => '16px',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',     // Attention! Firefox don't allow line-height less then 1.5em in the select
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0.1px',
				),
				'info'    => array(
					'title'           => esc_html__( 'Post meta', 'chinchilla' ),
					'description'     => sprintf( $font_description, esc_html__( 'post meta (author, categories, publish date, counters, share, etc.)', 'chinchilla' ) ),
					'font-family'     => 'inherit',
					'font-size'       => '14px',  // Old value '13px' don't allow using 'font zoom' in the custom blog items
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '0.4em',
					'margin-bottom'   => '',
				),
				'menu'    => array(
					'title'           => esc_html__( 'Main menu', 'chinchilla' ),
					'description'     => sprintf( $font_description, esc_html__( 'main menu items', 'chinchilla' ) ),
					'font-family'     => 'Laila,sans-serif',
					'font-size'       => '17px',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'submenu' => array(
					'title'           => esc_html__( 'Dropdown menu', 'chinchilla' ),
					'description'     => sprintf( $font_description, esc_html__( 'dropdown menu items', 'chinchilla' ) ),
					'font-family'     => 'Nunito,sans-serif',
					'font-size'       => '15px',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'other' => array(
					'title'           => esc_html__( 'Other', 'chinchilla' ),
					'description'     => sprintf( $font_description, esc_html__( 'specific elements', 'chinchilla' ) ),
					'font-family'     => 'Nunito,sans-serif',
				),
			)
		);

		// Font presets
		chinchilla_storage_set(
			'font_presets', array(
				'karla' => array(
								'title'  => esc_html__( 'Karla', 'chinchilla' ),
								'load_fonts' => array(
													// Google font
													array(
														'name'   => 'Dancing Script',
														'family' => 'fantasy',
														'link'   => '',
														'styles' => '300,400,700',
													),
													// Google font
													array(
														'name'   => 'Sansita Swashed',
														'family' => 'fantasy',
														'link'   => '',
														'styles' => '300,400,700',
													),
												),
								'theme_fonts' => array(
													'p'       => array(
														'font-family'     => '"Dancing Script",fantasy',
														'font-size'       => '1.25rem',
													),
													'post'    => array(
														'font-family'     => '',
													),
													'h1'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
														'font-size'       => '4em',
													),
													'h2'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h3'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h4'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h5'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h6'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'logo'    => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'button'  => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'input'   => array(
														'font-family'     => 'inherit',
													),
													'info'    => array(
														'font-family'     => 'inherit',
													),
													'menu'    => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'submenu' => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
												),
							),
				'roboto' => array(
								'title'  => esc_html__( 'Roboto', 'chinchilla' ),
								'load_fonts' => array(
													// Google font
													array(
														'name'   => 'Noto Sans JP',
														'family' => 'serif',
														'link'   => '',
														'styles' => '300,300italic,400,400italic,700,700italic',
													),
													// Google font
													array(
														'name'   => 'Merriweather',
														'family' => 'sans-serif',
														'link'   => '',
														'styles' => '300,300italic,400,400italic,700,700italic',
													),
												),
								'theme_fonts' => array(
													'p'       => array(
														'font-family'     => '"Noto Sans JP",serif',
													),
													'post'    => array(
														'font-family'     => '',
													),
													'h1'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h2'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h3'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h4'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h5'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h6'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'logo'    => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'button'  => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'input'   => array(
														'font-family'     => 'inherit',
													),
													'info'    => array(
														'font-family'     => 'inherit',
													),
													'menu'    => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'submenu' => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
												),
							),
				'garamond' => array(
								'title'  => esc_html__( 'Garamond', 'chinchilla' ),
								'load_fonts' => array(
													// Adobe font
													array(
														'name'   => 'Europe',
														'family' => 'sans-serif',
														'link'   => 'https://use.typekit.net/qmj1tmx.css',
														'styles' => '',
													),
													// Adobe font
													array(
														'name'   => 'Sofia Pro',
														'family' => 'sans-serif',
														'link'   => 'https://use.typekit.net/qmj1tmx.css',
														'styles' => '',
													),
												),
								'theme_fonts' => array(
													'p'       => array(
														'font-family'     => '"Sofia Pro",sans-serif',
													),
													'post'    => array(
														'font-family'     => '',
													),
													'h1'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h2'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h3'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h4'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h5'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h6'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'logo'    => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'button'  => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'input'   => array(
														'font-family'     => 'inherit',
													),
													'info'    => array(
														'font-family'     => 'inherit',
													),
													'menu'    => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'submenu' => array(
														'font-family'     => 'Europe,sans-serif',
													),
												),
							),
			)
		);
	}
}


//--------------------------------------------
// COLOR SCHEMES
//--------------------------------------------
if ( ! function_exists( 'chinchilla_skin_setup_schemes' ) ) {
	add_action( 'after_setup_theme', 'chinchilla_skin_setup_schemes', 1 );
	function chinchilla_skin_setup_schemes() {

		// Theme colors for customizer
		// Attention! Inner scheme must be last in the array below
		chinchilla_storage_set(
			'scheme_color_groups', array(
				'main'    => array(
					'title'       => esc_html__( 'Main', 'chinchilla' ),
					'description' => esc_html__( 'Colors of the main content area', 'chinchilla' ),
				),
				'alter'   => array(
					'title'       => esc_html__( 'Alter', 'chinchilla' ),
					'description' => esc_html__( 'Colors of the alternative blocks (sidebars, etc.)', 'chinchilla' ),
				),
				'extra'   => array(
					'title'       => esc_html__( 'Extra', 'chinchilla' ),
					'description' => esc_html__( 'Colors of the extra blocks (dropdowns, price blocks, table headers, etc.)', 'chinchilla' ),
				),
				'inverse' => array(
					'title'       => esc_html__( 'Inverse', 'chinchilla' ),
					'description' => esc_html__( 'Colors of the inverse blocks - when link color used as background of the block (dropdowns, blockquotes, etc.)', 'chinchilla' ),
				),
				'input'   => array(
					'title'       => esc_html__( 'Input', 'chinchilla' ),
					'description' => esc_html__( 'Colors of the form fields (text field, textarea, select, etc.)', 'chinchilla' ),
				),
			)
		);

		chinchilla_storage_set(
			'scheme_color_names', array(
				'bg_color'    => array(
					'title'       => esc_html__( 'Background color', 'chinchilla' ),
					'description' => esc_html__( 'Background color of this block in the normal state', 'chinchilla' ),
				),
				'bg_hover'    => array(
					'title'       => esc_html__( 'Background hover', 'chinchilla' ),
					'description' => esc_html__( 'Background color of this block in the hovered state', 'chinchilla' ),
				),
				'bd_color'    => array(
					'title'       => esc_html__( 'Border color', 'chinchilla' ),
					'description' => esc_html__( 'Border color of this block in the normal state', 'chinchilla' ),
				),
				'bd_hover'    => array(
					'title'       => esc_html__( 'Border hover', 'chinchilla' ),
					'description' => esc_html__( 'Border color of this block in the hovered state', 'chinchilla' ),
				),
				'text'        => array(
					'title'       => esc_html__( 'Text', 'chinchilla' ),
					'description' => esc_html__( 'Color of the text inside this block', 'chinchilla' ),
				),
				'text_dark'   => array(
					'title'       => esc_html__( 'Text dark', 'chinchilla' ),
					'description' => esc_html__( 'Color of the dark text (bold, header, etc.) inside this block', 'chinchilla' ),
				),
				'text_light'  => array(
					'title'       => esc_html__( 'Text light', 'chinchilla' ),
					'description' => esc_html__( 'Color of the light text (post meta, etc.) inside this block', 'chinchilla' ),
				),
				'text_link'   => array(
					'title'       => esc_html__( 'Link', 'chinchilla' ),
					'description' => esc_html__( 'Color of the links inside this block', 'chinchilla' ),
				),
				'text_hover'  => array(
					'title'       => esc_html__( 'Link hover', 'chinchilla' ),
					'description' => esc_html__( 'Color of the hovered state of links inside this block', 'chinchilla' ),
				),
				'text_link2'  => array(
					'title'       => esc_html__( 'Accent 2', 'chinchilla' ),
					'description' => esc_html__( 'Color of the accented texts (areas) inside this block', 'chinchilla' ),
				),
				'text_hover2' => array(
					'title'       => esc_html__( 'Accent 2 hover', 'chinchilla' ),
					'description' => esc_html__( 'Color of the hovered state of accented texts (areas) inside this block', 'chinchilla' ),
				),
				'text_link3'  => array(
					'title'       => esc_html__( 'Accent 3', 'chinchilla' ),
					'description' => esc_html__( 'Color of the other accented texts (buttons) inside this block', 'chinchilla' ),
				),
				'text_hover3' => array(
					'title'       => esc_html__( 'Accent 3 hover', 'chinchilla' ),
					'description' => esc_html__( 'Color of the hovered state of other accented texts (buttons) inside this block', 'chinchilla' ),
				),
			)
		);

		// Default values for each color scheme
		$schemes = array(

			// Color scheme: 'default'
			'default' => array(
				'title'    => esc_html__( 'Default', 'chinchilla' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#F5F9FA', //ok
					'bd_color'         => '#DBE3E5', //ok

					// Text and links colors
					'text'             => '#5B6A76', //ok
					'text_light'       => '#7F8F9B', //ok
					'text_dark'        => '#051829', //ok
					'text_link'        => '#B4C408', //ok
					'text_hover'       => '#A9B805', //ok
					'text_link2'       => '#DF3F52', //ok
					'text_hover2'      => '#CE3547', //ok
					'text_link3'       => '#34C1E7', //ok
					'text_hover3'      => '#24B0D5', //ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#FFFFFF', //ok
					'alter_bg_hover'   => '#E7EFF1', //ok
					'alter_bd_color'   => '#DBE3E5', //ok
					'alter_bd_hover'   => '#C7D2D5', //ok
					'alter_text'       => '#5B6A76', //ok
					'alter_light'      => '#7F8F9B', //ok
					'alter_dark'       => '#051829', //ok
					'alter_link'       => '#B4C408', //ok
					'alter_hover'      => '#A9B805', //ok
					'alter_link2'      => '#DF3F52', //ok
					'alter_hover2'     => '#CE3547', //ok
					'alter_link3'      => '#34C1E7', //ok
					'alter_hover3'     => '#24B0D5', //ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#0F0606', //ok
					'extra_bg_hover'   => '#201818',
					'extra_bd_color'   => '#443D3D',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#8E98A1', //ok
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#FFFFFF', //ok
					'extra_link'       => '#B4C408', //ok
					'extra_hover'      => '#FFFFFF', //ok
					'extra_link2'      => '#DF3F52',
					'extra_hover2'     => '#CE3547',
					'extra_link3'      => '#34C1E7',
					'extra_hover3'     => '#24B0D5',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //ok
					'input_bg_hover'   => 'transparent', //ok
					'input_bd_color'   => '#DBE3E5', //ok
					'input_bd_hover'   => '#C7D2D5', //ok
					'input_text'       => '#5B6A76', //ok
					'input_light'      => '#7F8F9B', //ok
					'input_dark'       => '#051829', //ok

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#051829', //ok
					'inverse_link'     => '#FFFFFF', //ok
					'inverse_hover'    => '#FFFFFF', //ok  051829

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'dark'
			'dark'    => array(
				'title'    => esc_html__( 'Dark', 'chinchilla' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#07243E', //ok
					'bd_color'         => '#364D62', //ok

					// Text and links colors
					'text'             => '#BFC9D2', //ok
					'text_light'       => '#8E98A1', //ok
					'text_dark'        => '#F5F9FA', //ok
					'text_link'        => '#B4C408', //ok
					'text_hover'       => '#A9B805', //ok
					'text_link2'       => '#DF3F52', //ok
					'text_hover2'      => '#CE3547', //ok
					'text_link3'       => '#34C1E7', //ok
					'text_hover3'      => '#24B0D5', //ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#051C2F', //ok
					'alter_bg_hover'   => '#19344C', //ok
					'alter_bd_color'   => '#364D62', //ok
					'alter_bd_hover'   => '#526678', //ok
					'alter_text'       => '#BFC9D2', //ok
					'alter_light'      => '#8E98A1', //ok
					'alter_dark'       => '#F5F9FA', //ok
					'alter_link'       => '#B4C408', //ok
					'alter_hover'      => '#A9B805', //ok
					'alter_link2'      => '#DF3F52', //ok
					'alter_hover2'     => '#CE3547', //ok
					'alter_link3'      => '#34C1E7', //ok
					'alter_hover3'     => '#24B0D5', //ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#F5F9FA', //'#0F0606', //ok
					'extra_bg_hover'   => '#19344C',
					'extra_bd_color'   => '#DBE3E5',
					'extra_bd_hover'   => '#364D62',
					'extra_text'       => '#8E98A1', //ok
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#5B6A76', //ok
					'extra_link'       => '#5B6A76', //ok
					'extra_hover'      => '#B4C408', //ok
					'extra_link2'      => '#DF3F52',
					'extra_hover2'     => '#CE3547',
					'extra_link3'      => '#34C1E7',
					'extra_hover3'     => '#24B0D5',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => '#transparent', //ok
					'input_bg_hover'   => '#transparent', //ok
					'input_bd_color'   => '#364D62', //ok
					'input_bd_hover'   => '#526678', //ok
					'input_text'       => '#BFC9D2', //ok
					'input_light'      => '#8E98A1', //ok
					'input_dark'       => '#F5F9FA', //ok

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#F5F9FA',
					'inverse_bd_hover' => '#F5F9FA',
					'inverse_text'     => '#F5F9FA', //ok
					'inverse_light'    => '#8E98A1',
					'inverse_dark'     => '#5B6A76', //ok
					'inverse_link'     => '#F5F9FA', //ok
					'inverse_hover'    => '#07243E', //ok

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

            // Color scheme: 'light'
            'light' => array(
                'title'    => esc_html__( 'Light', 'chinchilla' ),
                'internal' => true,
                'colors'   => array(

                    // Whole block border and background
                    'bg_color'         => '#FFFFFF', //ok
                    'bd_color'         => '#DBE3E5', //ok

                    // Text and links colors
                    'text'             => '#5B6A76', //ok
                    'text_light'       => '#7F8F9B', //ok
                    'text_dark'        => '#051829', //ok
                    'text_link'        => '#B4C408', //ok
                    'text_hover'       => '#A9B805', //ok
                    'text_link2'       => '#DF3F52', //ok
                    'text_hover2'      => '#CE3547', //ok
                    'text_link3'       => '#34C1E7', //ok
                    'text_hover3'      => '#24B0D5', //ok

                    // Alternative blocks (sidebar, tabs, alternative blocks, etc.)
                    'alter_bg_color'   => '#F5F9FA', //ok
                    'alter_bg_hover'   => '#FFFFFF', //ok
                    'alter_bd_color'   => '#DBE3E5', //ok
                    'alter_bd_hover'   => '#C7D2D5', //ok
                    'alter_text'       => '#5B6A76', //ok
                    'alter_light'      => '#7F8F9B', //ok
                    'alter_dark'       => '#051829', //ok
                    'alter_link'       => '#B4C408', //ok
                    'alter_hover'      => '#A9B805', //ok
                    'alter_link2'      => '#DF3F52', //ok
                    'alter_hover2'     => '#CE3547', //ok
                    'alter_link3'      => '#34C1E7', //ok
                    'alter_hover3'     => '#24B0D5', //ok

                    // Extra blocks (submenu, tabs, color blocks, etc.)
                    'extra_bg_color'   => '#0F0606', //ok
                    'extra_bg_hover'   => '#201818',
                    'extra_bd_color'   => '#443D3D',
                    'extra_bd_hover'   => '#575757',
                    'extra_text'       => '#8E98A1', //ok
                    'extra_light'      => '#afafaf',
                    'extra_dark'       => '#FFFFFF', //ok
                    'extra_link'       => '#B4C408', //ok
                    'extra_hover'      => '#FFFFFF', //ok
                    'extra_link2'      => '#DF3F52',
                    'extra_hover2'     => '#CE3547',
                    'extra_link3'      => '#34C1E7',
                    'extra_hover3'     => '#24B0D5',

                    // Input fields (form's fields and textarea)
                    'input_bg_color'   => 'transparent', //ok
                    'input_bg_hover'   => 'transparent', //ok
                    'input_bd_color'   => '#DBE3E5', //ok
                    'input_bd_hover'   => '#C7D2D5', //ok
                    'input_text'       => '#5B6A76', //ok
                    'input_light'      => '#7F8F9B', //ok
                    'input_dark'       => '#051829', //ok

                    // Inverse blocks (text and links on the 'text_link' background)
                    'inverse_bd_color' => '#67bcc1',
                    'inverse_bd_hover' => '#5aa4a9',
                    'inverse_text'     => '#1d1d1d',
                    'inverse_light'    => '#333333',
                    'inverse_dark'     => '#051829', //ok
                    'inverse_link'     => '#FFFFFF', //ok
                    'inverse_hover'    => '#FFFFFF', //ok

                    // Additional (skin-specific) colors.
                    // Attention! Set of colors must be equal in all color schemes.
                    //---> For example:
                    //---> 'new_color1'         => '#rrggbb',
                    //---> 'alter_new_color1'   => '#rrggbb',
                    //---> 'inverse_new_color1' => '#rrggbb',
                ),
            ),
		);
		chinchilla_storage_set( 'schemes', $schemes );
		chinchilla_storage_set( 'schemes_original', $schemes );

		// Add names of additional colors
		//---> For example:
		//---> chinchilla_storage_set_array( 'scheme_color_names', 'new_color1', array(
		//---> 	'title'       => __( 'New color 1', 'chinchilla' ),
		//---> 	'description' => __( 'Description of the new color 1', 'chinchilla' ),
		//---> ) );


		// Additional colors for each scheme
		// Parameters:	'color' - name of the color from the scheme that should be used as source for the transformation
		//				'alpha' - to make color transparent (0.0 - 1.0)
		//				'hue', 'saturation', 'brightness' - inc/dec value for each color's component
		chinchilla_storage_set(
			'scheme_colors_add', array(
				'bg_color_0'        => array(
					'color' => 'bg_color',
					'alpha' => 0,
				),
				'bg_color_02'       => array(
					'color' => 'bg_color',
					'alpha' => 0.2,
				),
				'bg_color_07'       => array(
					'color' => 'bg_color',
					'alpha' => 0.7,
				),
				'bg_color_08'       => array(
					'color' => 'bg_color',
					'alpha' => 0.8,
				),
				'bg_color_09'       => array(
					'color' => 'bg_color',
					'alpha' => 0.9,
				),
				'alter_bg_color_07' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.7,
				),
				'alter_bg_color_04' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.4,
				),
				'alter_bg_color_00' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0,
				),
				'alter_bg_color_02' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.2,
				),
				'alter_bd_color_02' => array(
					'color' => 'alter_bd_color',
					'alpha' => 0.2,
				),
                'alter_dark_003'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.03,
                ),
                'alter_dark_015'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.15,
                ),
                'alter_dark_02'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.2,
                ),
                'alter_dark_05'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.5,
                ),
                'alter_dark_08'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.8,
                ),
				'alter_link_02'     => array(
					'color' => 'alter_link',
					'alpha' => 0.2,
				),
				'alter_link_07'     => array(
					'color' => 'alter_link',
					'alpha' => 0.7,
				),
				'extra_bg_color_05' => array(
					'color' => 'extra_bg_color',
					'alpha' => 0.5,
				),
				'extra_bg_color_07' => array(
					'color' => 'extra_bg_color',
					'alpha' => 0.7,
				),
				'extra_link_02'     => array(
					'color' => 'extra_link',
					'alpha' => 0.2,
				),
				'extra_link_07'     => array(
					'color' => 'extra_link',
					'alpha' => 0.7,
				),
                'text_dark_003'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.03,
                ),
                'text_dark_005'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.05,
                ),
                'text_dark_008'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.08,
                ),
				'text_dark_015'      => array(
					'color' => 'text_dark',
					'alpha' => 0.15,
				),
				'text_dark_02'      => array(
					'color' => 'text_dark',
					'alpha' => 0.2,
				),
                'text_dark_03'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.3,
                ),
                'text_dark_05'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.5,
                ),
				'text_dark_07'      => array(
					'color' => 'text_dark',
					'alpha' => 0.7,
				),
                'text_dark_08'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.8,
                ),
                'text_link_007'      => array(
                    'color' => 'text_link',
                    'alpha' => 0.07,
                ),
				'text_link_02'      => array(
					'color' => 'text_link',
					'alpha' => 0.2,
				),
                'text_link_03'      => array(
                    'color' => 'text_link',
                    'alpha' => 0.3,
                ),
				'text_link_04'      => array(
					'color' => 'text_link',
					'alpha' => 0.4,
				),
                'text_link_05'      => array(
                    'color' => 'text_link',
                    'alpha' => 0.5,
                ),
				'text_link_07'      => array(
					'color' => 'text_link',
					'alpha' => 0.7,
				),
                'text_link2_007'      => array(
                    'color' => 'text_link2',
                    'alpha' => 0.07,
                ),
				'text_link2_02'      => array(
					'color' => 'text_link2',
					'alpha' => 0.2,
				),
                'text_link2_03'      => array(
                    'color' => 'text_link2',
                    'alpha' => 0.3,
                ),
				'text_link2_05'      => array(
					'color' => 'text_link2',
					'alpha' => 0.5,
				),
                'text_link2_085'      => array(
                    'color' => 'text_link2',
                    'alpha' => 0.85,
                ),
                'text_link3_007'      => array(
                    'color' => 'text_link3',
                    'alpha' => 0.07,
                ),
				'text_link3_02'      => array(
					'color' => 'text_link3',
					'alpha' => 0.2,
				),
                'text_link3_03'      => array(
                    'color' => 'text_link3',
                    'alpha' => 0.3,
                ),
                'inverse_text_03'      => array(
                    'color' => 'inverse_text',
                    'alpha' => 0.3,
                ),
                'inverse_link_08'      => array(
                    'color' => 'inverse_link',
                    'alpha' => 0.8,
                ),
                'inverse_hover_08'      => array(
                    'color' => 'inverse_hover',
                    'alpha' => 0.8,
                ),
				'text_dark_blend'   => array(
					'color'      => 'text_dark',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
				'text_link_blend'   => array(
					'color'      => 'text_link',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
				'alter_link_blend'  => array(
					'color'      => 'alter_link',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
			)
		);

		// Simple scheme editor: lists the colors to edit in the "Simple" mode.
		// For each color you can set the array of 'slave' colors and brightness factors that are used to generate new values,
		// when 'main' color is changed
		// Leave 'slave' arrays empty if your scheme does not have a color dependency
		chinchilla_storage_set(
			'schemes_simple', array(
				'text_link'        => array(
					'alter_hover'      => 1,
					'extra_link'       => 1,
					'inverse_bd_color' => 0.85,
					'inverse_bd_hover' => 0.7,
				),
				'text_hover'       => array(
					'alter_link'  => 1,
					'extra_hover' => 1,
				),
				'text_link2'       => array(
					'alter_hover2' => 1,
					'extra_link2'  => 1,
				),
				'text_hover2'      => array(
					'alter_link2'  => 1,
					'extra_hover2' => 1,
				),
				'text_link3'       => array(
					'alter_hover3' => 1,
					'extra_link3'  => 1,
				),
				'text_hover3'      => array(
					'alter_link3'  => 1,
					'extra_hover3' => 1,
				),
				'alter_link'       => array(),
				'alter_hover'      => array(),
				'alter_link2'      => array(),
				'alter_hover2'     => array(),
				'alter_link3'      => array(),
				'alter_hover3'     => array(),
				'extra_link'       => array(),
				'extra_hover'      => array(),
				'extra_link2'      => array(),
				'extra_hover2'     => array(),
				'extra_link3'      => array(),
				'extra_hover3'     => array(),
				'inverse_bd_color' => array(),
				'inverse_bd_hover' => array(),
			)
		);

		// Parameters to set order of schemes in the css
		chinchilla_storage_set(
			'schemes_sorted', array(
				'color_scheme',
				'header_scheme',
				'menu_scheme',
				'sidebar_scheme',
				'footer_scheme',
			)
		);

		// Color presets
		chinchilla_storage_set(
			'color_presets', array(
				'autumn' => array(
								'title'  => esc_html__( 'Autumn', 'chinchilla' ),
								'colors' => array(
												'default' => array(
																	'text_link'  => '#d83938',
																	'text_hover' => '#f2b232',
																	),
												'dark' => array(
																	'text_link'  => '#d83938',
																	'text_hover' => '#f2b232',
																	)
												)
							),
				'green' => array(
								'title'  => esc_html__( 'Natural Green', 'chinchilla' ),
								'colors' => array(
												'default' => array(
																	'text_link'  => '#75ac78',
																	'text_hover' => '#378e6d',
																	),
												'dark' => array(
																	'text_link'  => '#75ac78',
																	'text_hover' => '#378e6d',
																	)
												)
							),
			)
		);
	}
}

// Activation methods
if ( ! function_exists( 'qwery_skin_filter_activation_methods2' ) ) {
    add_filter( 'trx_addons_filter_activation_methods', 'qwery_skin_filter_activation_methods2', 11, 1 );
    function qwery_skin_filter_activation_methods2( $args ) {
        $args['elements_key'] = true;
        return $args;
    }
}

// Enqueue clone specific style
if ( ! function_exists( 'chinchilla_clone_frontend_scripts' ) ) {
    add_action( 'wp_enqueue_scripts', 'chinchilla_clone_frontend_scripts', 1150 );
    function chinchilla_clone_frontend_scripts() {
        $chinchilla_url = chinchilla_get_file_url( chinchilla_skins_get_current_skin_dir() . 'extra-style.css' );
        if ( '' != $chinchilla_url ) {
            wp_enqueue_style( 'chinchilla-extra-skin-' . esc_attr( chinchilla_skins_get_current_skin_name() ), $chinchilla_url, array(), null );
        }
    }
}
